==> breeze_update_3.6.05.tar.gz: php/error_msg.php <==
<?php
	include("../connect/config.php");
	
	if (BWB_BASE_DIR == "")
		$rel_path = "/";
	else
		$rel_path = "/" . BWB_BASE_DIR . "/";
		
	$query = "SELECT title FROM " . BWB_TABLE_PREFIX . "page_titles WHERE page_name='_default_'";
	$result = mysql_query($query, $bwb_link);
	$row = mysql_fetch_array($result);
	$title = $row["title"];
	$title = stripslashes($title);
	
	$go_back = str_replace("password_reset=1", "password_reset=0", $go_back);
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title><?php echo $title; ?></title>
<META NAME="ROBOTS" CONTENT="NOINDEX, NOFOLLOW">

<?php
echo "<link rel=\"stylesheet\" href=\"" . $rel_path . BWB_CSS_DIR . "/site.css\" type=\"text/css\">\n";
?>
<link rel="stylesheet" type="text/css" href="https://fonts.googleapis.com/css?family=Open+Sans:400,300,400italic,600,600italic,700,700italic,300italic&amp;subset=latin,latin-ext">
<link rel="stylesheet" type="text/css" href="https://fonts.googleapis.com/css">
</head>

<body>
	<div class="wrap" id="wrap">
    	<table width="100%" border="0" cellspacing="0" cellpadding="0">
    		<tr>
    			<td valign="top" class="content_td" id="content_td">
   					<div class="content_div" id="content_div">
    
                        <div class="popup_msg_div">
                        <table class="popup_msg_table">
                          <tr>          
                            <td class="popup_msg_td_top">
                                <?php echo $err; ?>
                            </td>
                          </tr>
                          <tr>
                            <td class="popup_msg_td_bottom">
                            <a href="<?php echo $go_back; ?>">
                              <input type="button" name="go_back" value="<?php echo $button_label; ?>"  class="popup_msg_button" onclick="window.location='<?php echo $go_back; ?>';" />
                            </a>
                            </td>
                          </tr>
                        </table>
                        </div>
                        
					</div>
				</td>
			</tr>
		</table>
	</div>
</body>
</html>

==> breeze_update_4.0.01.tar.gz: php/error_msg.php <==
<?php
	include("../connect/config.php");
	
	if (BWB_BASE_DIR == "")
		$rel_path = "/";
	else
		$rel_path = "/" . BWB_BASE_DIR . "/";
		
	$query = "SELECT title FROM " . BWB_TABLE_PREFIX . "page_titles WHERE page_name='_default_'";
	$result = $bwb_dbh->query($query);
	$row = $result->fetch(PDO::FETCH_ASSOC);
	$title = $row["title"];
	$title = stripslashes($title);
	
	$go_back = str_replace("password_reset=1", "password_reset=0", $go_back);
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title><?php echo $title; ?></title>
<META NAME="ROBOTS" CONTENT="NOINDEX, NOFOLLOW">

<?php
echo "<link rel=\"stylesheet\" href=\"" . $rel_path . BWB_CSS_DIR . "/site.css\" type=\"text/css\">\n";
?>
<link rel="stylesheet" type="text/css" href="https://fonts.googleapis.com/css?family=Open+Sans:400,300,400italic,600,600italic,700,700italic,300italic&amp;subset=latin,latin-ext">
<link rel="stylesheet" type="text/css" href="https://fonts.googleapis.com/css">
</head>

<body>
	<div class="wrap" id="wrap">
    	<table width="100%" border="0" cellspacing="0" cellpadding="0">
    		<tr>
    			<td valign="top" class="content_td" id="content_td">
   					<div class="content_div" id="content_div">
    
                        <div class="popup_msg_div">
                        <table class="popup_msg_table">
                          <tr>          
                            <td class="popup_msg_td_top">
                                <?php echo $err; ?>
                            </td>
                          </tr>
                          <tr>
                            <td class="popup_msg_td_bottom">
                            <a href="<?php echo $go_back; ?>">
                              <input type="button" name="go_back" value="<?php echo $button_label; ?>"  class="popup_msg_button" onclick="window.location='<?php echo $go_back; ?>';" />
                            </a>
                            </td>
                          </tr>
                        </table>
                        </div>
                        
					</div>
				</td>
			</tr>
		</table>
	</div>
</body>
</html>
